# `cramjam` docs

GitHub: [cramjam](https://www.github.com/milesgranger/cramjam).

## What?

`cramjam` is a de/compression library containing a multitude of compression codecs
in a single, easy to install, and similar as possible API.

---

## Supported Codecs

* lz4
* gzip
* brotli
* snappy
* xz/lzma
* deflate
* zstd
* bzip
* blosc2 (experimental support)

---

## Languages

- [x] [CLI](https://github.com/milesgranger/cramjam/tree/master/cramjam-cli)  
    - `pip install cramjam-cli`
- [x] [Python](https://github.com/milesgranger/cramjam/tree/master/cramjam-python)  
    - `pip install cramjam`
    - `conda install -c conda-forge cramjam`
- [x] [Rust](https://github.com/milesgranger/cramjam/tree/master/libcramjam)  
    - `cargo add libcramjam`
- [x] [C](https://github.com/milesgranger/cramjam/tree/master/libcramjam)  
    - `cargo add libcramjam --features capi`
- [ ] JavaScript (TODO)
